camelot.camelot.view.controls.editors.ImageEditor

Package camelot :: Package camelot :: Package view :: Package controls :: Module editors :: Class ImageEditor |
[hide private]
[frames] | no frames]

# Class ImageEditor

source code

Instance Methods | [hide private]
__init__(self, parent=None) | source code
dragEnterEvent(self, event) | source code
dragMoveEvent(self, event) | source code
dropEvent(self, event) | source code
clearImage(self) | source code
openFileDialog(self) | source code
openInApp(self) | source code
pilimage_from_file(self, filepath) | source code
draw_border(self) | source code
setPixmap(self, pixmap) | source code
clearFirstImage(self) | source code